@@ -522,7 +522,7 @@ void XMLHttpRequest::send(const QString &_body, int &ec)
             QString key = i.key().original();
             QString value = i.value();
             if (key.toLower() == "accept") {
-                // The HTTP KIO slave supports an override this way
+                // The HTTP KIO worker supports an override this way
                 job->addMetaData("accept", value);
             } else {
                 if (!rh.isEmpty()) {
@@ -990,3 +990,4 @@ JSValue *XMLHttpRequestProtoFunc::callAsFunction(ExecState *exec, JSObject *this
 
 } // end namespace
 
+#include "moc_xmlhttprequest.cpp"
