@@ -46,8 +46,6 @@
 
 #include <QStack>
 //Added by qt3to4:
-#include <QTimerEvent>
-#include <QList>
 #include "khtml_debug.h"
 #include <klocalizedstring.h>
 
@@ -2127,7 +2125,7 @@ void DocumentImpl::processHttpEquiv(const DOMString &equiv, const DOMString &con
         d->setCookie(content);
     } else if (strcasecmp(equiv, "default-style") == 0) {
         // HTML 4.0 14.3.2
-        // http://www.hixie.ch/tests/evil/css/import/main/preferred.html
+        // https://www.hixie.ch/tests/evil/css/import/main/preferred.html
         m_preferredStylesheetSet = content;
         updateStyleSelector();
     } else if (strcasecmp(equiv, "content-language") == 0) {
@@ -3417,3 +3415,4 @@ void XMLDocumentImpl::close()
     }
 }
 
+#include "moc_dom_docimpl.cpp"
