@@ -25,7 +25,6 @@
 
 #include <QFile>
 #include <QTimer>
-#include <QProcess>
 #include <QFileInfo>
 #include <QTextStream>
 #include <QFileDialog>
@@ -1191,3 +1190,4 @@ void TestRegressionWindow::writeListFile(const QString &fileName, const QStringL
     file.close();
 }
 
+#include "moc_test_regression_gui_window.cpp"
